@@ -44,13 +44,13 @@ LDAP_VALID_UID_RE = re.compile(r"^[a-z0-9][a-z0-9_-]+$")
 # NOTE: this value was chosen to ensure enough lower-value
 #       UIDs were available for service accounts, until we
 #       reach the heat death of the universe.
-MINIMUM_USER_UID = '6000'
+MINIMUM_USER_UID = 6000
 
 # New service account UIDs will be larger than this value,
 # but below that of MINIMUM_UID.
 # NOTE: since the GID is chosen to match the UID, we start
 #       at 5010, to avoid collision with: "nacho" uid=1122 gid=5004
-MINIMUM_SVC_UID = '5010'
+MINIMUM_SVC_UID = 5010
 
 assert MINIMUM_USER_UID > MINIMUM_SVC_UID
 
@@ -326,7 +326,7 @@ class manager:
             assert(type(avail_uids) is list and len(avail_uids) > 0 and type(avail_gids) is list and len(avail_gids) > 0)
 
             for uid in avail_uids:
-                if uid >= MINIMUM_USER_UID and uid in avail_gids:
+                if uid >= MINIMUM_USER_UID and uid in avail_uids:
                     return(uid)
                     break
                 continue
